@@ -1,7 +1,7 @@
 #' @rdname before-and-after
 #' @export
 str_before_nth <- function(string, pattern, n) {
-  if (all_equal(string, character())) return(character())
+  if (is_l0_char(string)) return(character())
   verify_string_pattern_n(string, pattern, n)
   nth_instance_indices <- str_locate_nth(string, pattern, n)
   str_sub(string, 1, nth_instance_indices[, "start"] - 1)
@@ -35,7 +35,7 @@ str_before_last <- function(string, pattern) {
 #' @family bisectors
 #' @export
 str_before_last_dot <- function(string) {
-  if (all_equal(string, character())) return(character())
+  if (is_l0_char(string)) return(character())
   checkmate::assert_character(string)
   string %>%
     tools::file_path_sans_ext() %T>% {
